LpPin

Trait LpPin 

pub trait LpPin: Pin {
    // Required method
    fn lp_number(&self) -> u8;
}
Available on crate feature unstable only.
Trait implemented by the pins that the low-power domain can reach.

The low-power domain has its own numbers for these pads, and the low-power registers take such a number. Only some chips give a pad the same number in both domains, so do not mix the two numbers. Give Self::lp_number to the low-power registers, and Pin::number to the digital registers.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Required Methods

fn lp_number(&self) -> u8

LP number of the pin

Implementors

Source

impl LpPin for GPIO0<'_>

Source

impl LpPin for GPIO2<'_>

Source

impl LpPin for GPIO4<'_>

Source

impl LpPin for GPIO12<'_>

Source

impl LpPin for GPIO13<'_>

Source

impl LpPin for GPIO14<'_>

Source

impl LpPin for GPIO15<'_>

Source

impl LpPin for GPIO25<'_>

Source

impl LpPin for GPIO26<'_>

Source

impl LpPin for GPIO27<'_>

Source

impl LpPin for GPIO32<'_>

Source

impl LpPin for GPIO33<'_>

Source

impl LpPin for GPIO34<'_>

Source

impl LpPin for GPIO35<'_>

Source

impl LpPin for GPIO36<'_>

Source

impl LpPin for GPIO37<'_>

Source

impl LpPin for GPIO38<'_>

Source

impl LpPin for GPIO39<'_>